@@ -58,10 +58,10 @@
       (red-faint       "#d08f72")
       (green           "#2fa526")
       (green-warmer    "#64aa0f")
-      (green-cooler    "#00b672")
+      (green-cooler    "#00b066")
       (green-faint     "#519068")
-      (yellow          "#c48502")
-      (yellow-warmer   "#e0832f")
+      (yellow          "#c48702")
+      (yellow-warmer   "#d0730f")
       (yellow-cooler   "#df8f6f")
       (yellow-faint    "#cf9f7f")
       (blue            "#379cf6")
@@ -98,6 +98,20 @@
       (bg-removed-faint  "#330a00")
       (bg-removed-refine "#6a1a16")
 
+      ;; Graphs
+      (red-graph-0-bg     "#b52c2c")
+      (red-graph-1-bg     "#702020")
+      (green-graph-0-bg   "#4fd100")
+      (green-graph-1-bg   "#007800")
+      (yellow-graph-0-bg  "#f1e00a")
+      (yellow-graph-1-bg  "#b08600")
+      (blue-graph-0-bg    "#2fafef")
+      (blue-graph-1-bg    "#1f2f8f")
+      (magenta-graph-0-bg "#bf94fe")
+      (magenta-graph-1-bg "#5f509f")
+      (cyan-graph-0-bg    "#47dfea")
+      (cyan-graph-1-bg    "#00808f")
+
       ;; Special hues
       (bg-mode-line  "#692a12") (fg-mode-line  "#feeeca")
       (bg-accent     "#ffa200") (fg-accent     "#000000")
@@ -108,6 +122,7 @@
       (bg-region     "#3f1020")
       (bg-paren      "#7f2d40")
       (bg-err        "#361400") ; check with err
+      (bg-warning    "#332800") ; check with warning
       (bg-info       "#152800") ; check with info
 
       (border        "#54444a")
@@ -152,7 +167,7 @@
       (rainbow-2 magenta)
       (rainbow-3 blue-warmer)
       (rainbow-4 red)
-      (rainbow-5 green-cooler)
+      (rainbow-5 green)
       (rainbow-6 magenta-warmer)
       (rainbow-7 cyan)
       (rainbow-8 yellow))
