@@ -98,6 +98,20 @@
       (bg-removed-faint  "#320a0f")
       (bg-removed-refine "#751a1f")
 
+      ;; Graphs
+      (red-graph-0-bg     "#b52c2c")
+      (red-graph-1-bg     "#702020")
+      (green-graph-0-bg   "#4fd100")
+      (green-graph-1-bg   "#007800")
+      (yellow-graph-0-bg  "#f1e00a")
+      (yellow-graph-1-bg  "#b08600")
+      (blue-graph-0-bg    "#2fafef")
+      (blue-graph-1-bg    "#1f2f8f")
+      (magenta-graph-0-bg "#bf94fe")
+      (magenta-graph-1-bg "#5f509f")
+      (cyan-graph-0-bg    "#47dfea")
+      (cyan-graph-1-bg    "#00808f")
+
       ;; Special hues
       (bg-mode-line  "#2a2a75") (fg-mode-line  "#e0e0ff")
       (bg-accent     "#25adff") (fg-accent     "#000000")
@@ -108,6 +122,7 @@
       (bg-region     "#25164a")
       (bg-paren      "#20577a")
       (bg-err        "#330d09") ; check with err
+      (bg-warning    "#332600") ; check with warning
       (bg-info       "#002212") ; check with info
 
       (border        "#444f5f")
@@ -154,7 +169,7 @@
       (rainbow-4 yellow-cooler)
       (rainbow-5 magenta-cooler)
       (rainbow-6 red-cooler)
-      (rainbow-7 green)
+      (rainbow-7 green-warmer)
       (rainbow-8 yellow))
     "The `ef-dark' palette.")
 
