@@ -98,6 +98,20 @@
       (bg-removed-faint  "#ffe9e9")
       (bg-removed-refine "#f3b5af")
 
+      ;; Graphs
+      (red-graph-0-bg     "#ef7969")
+      (red-graph-1-bg     "#ffaab4")
+      (green-graph-0-bg   "#4faa09")
+      (green-graph-1-bg   "#8fef00")
+      (yellow-graph-0-bg  "#ffcf00")
+      (yellow-graph-1-bg  "#f9ff00")
+      (blue-graph-0-bg    "#7090ff")
+      (blue-graph-1-bg    "#9fc6ff")
+      (magenta-graph-0-bg "#e07fff")
+      (magenta-graph-1-bg "#fad0ff")
+      (cyan-graph-0-bg    "#70d3f0")
+      (cyan-graph-1-bg    "#afefff")
+
       ;; Special hues
       (bg-mode-line  "#b7c7ff") (fg-mode-line  "#151515")
       (bg-accent     "#0000cc") (fg-accent     "#ffffff")
@@ -108,6 +122,7 @@
       (bg-region     "#bfefff")
       (bg-paren      "#efa09f")
       (bg-err        "#ffd5ea") ; check with err
+      (bg-warning    "#ffeabb") ; check with warning
       (bg-info       "#d0efda") ; check with info
 
       (border        "#cecfff")
@@ -154,7 +169,7 @@
       (rainbow-4 yellow-cooler)
       (rainbow-5 magenta-cooler)
       (rainbow-6 red-cooler)
-      (rainbow-7 green)
+      (rainbow-7 green-cooler)
       (rainbow-8 yellow))
     "The `ef-light' palette.")
 
