@@ -98,6 +98,20 @@
       (bg-removed-faint  "#2f060f")
       (bg-removed-refine "#641426")
 
+      ;; Graphs
+      (red-graph-0-bg     "#b52c2c")
+      (red-graph-1-bg     "#702020")
+      (green-graph-0-bg   "#4fd100")
+      (green-graph-1-bg   "#007800")
+      (yellow-graph-0-bg  "#f1e00a")
+      (yellow-graph-1-bg  "#b08600")
+      (blue-graph-0-bg    "#2fafef")
+      (blue-graph-1-bg    "#1f2f8f")
+      (magenta-graph-0-bg "#bf94fe")
+      (magenta-graph-1-bg "#5f509f")
+      (cyan-graph-0-bg    "#47dfea")
+      (cyan-graph-1-bg    "#00808f")
+
       ;; Special hues
       (bg-mode-line  "#003a7f") (fg-mode-line  "#ceeeff")
       (bg-accent     "#ff9270") (fg-accent     "#000000")
@@ -108,10 +122,11 @@
       (bg-region     "#222f40")
       (bg-paren      "#703350")
       (bg-err        "#331419") ; check with err
+      (bg-warning    "#332613") ; check with warning
       (bg-info       "#00251f") ; check with info
 
       (border        "#34445a")
-      (cursor        "#00ccaf")
+      (cursor        "#00ccff")
       (fg-intense    "#ffffff")
 
       ;; Mappings
@@ -152,7 +167,7 @@
       (rainbow-2 yellow-cooler)
       (rainbow-3 blue-warmer)
       (rainbow-4 red)
-      (rainbow-5 green-cooler)
+      (rainbow-5 green)
       (rainbow-6 magenta)
       (rainbow-7 cyan)
       (rainbow-8 yellow))
